cgexplore.terms.TargetPyramidAngle
==================================

.. currentmodule:: cgexplore.terms

.. autoclass:: TargetPyramidAngle
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~TargetPyramidAngle.human_readable
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TargetPyramidAngle.opposite_angle
      ~TargetPyramidAngle.angle
      ~TargetPyramidAngle.angle_k
      ~TargetPyramidAngle.element1
      ~TargetPyramidAngle.element2
      ~TargetPyramidAngle.element3
      ~TargetPyramidAngle.type1
      ~TargetPyramidAngle.type2
      ~TargetPyramidAngle.type3
   
   